PaymentHash

Struct PaymentHash 

pub struct PaymentHash(/* private fields */);
A 32-byte payment hash.

The payment hash is the SHA256 hash of the preimage and is used to identify payments in the Lightning Network.

Implementations

Source

impl PaymentHash

pub fn from_bytes(bytes: [u8; 32]) -> Self

Create a new payment hash from bytes.

pub fn from_hex(hex: &str) -> Result<Self, LightningError>

Create a new payment hash from a hex string.

pub fn as_bytes(&self) -> &[u8; 32]

Get the raw bytes.

pub fn to_hex(&self) -> String

Convert to hex string.

pub fn verify(&self, preimage: &PaymentPreimage) -> bool

Verify that a preimage matches this payment hash.