pub struct PaymentPreimage(/* private fields */);Expand description
A 32-byte payment preimage.
The preimage is the secret that, when hashed with SHA256, produces the payment hash. Revealing the preimage proves that a payment was received.
Implementations
Sourceimpl PaymentPreimage
impl PaymentPreimage
Sourcepub fn from_bytes(bytes: [u8; 32]) -> Self
pub fn from_bytes(bytes: [u8; 32]) -> Self
Create a new payment preimage from bytes.
Sourcepub fn from_hex(hex: &str) -> Result<Self, LightningError>
pub fn from_hex(hex: &str) -> Result<Self, LightningError>
Create a new payment preimage from a hex string.
Sourcepub fn payment_hash(&self) -> PaymentHash
pub fn payment_hash(&self) -> PaymentHash
Compute the payment hash from this preimage.