pub struct RouteHint { /* private fields */ }Expand description
A route hint for finding a path to a destination.
Route hints are used when the destination has private channels that are not publicly announced.
Implementations
Sourceimpl RouteHint
impl RouteHint
Sourcepub fn with_hops(hops: Vec<RouteHintHop>) -> Self
pub fn with_hops(hops: Vec<RouteHintHop>) -> Self
Create a route hint with the given hops.
Sourcepub fn add_hop(&mut self, hop: RouteHintHop)
pub fn add_hop(&mut self, hop: RouteHintHop)
Add a hop to the route hint.
Sourcepub fn hops(&self) -> &[RouteHintHop]
pub fn hops(&self) -> &[RouteHintHop]
Get the hops in this route hint.