pub struct PaymentHash(/* private fields */);Expand description
A 32-byte payment hash.
The payment hash is the SHA256 hash of the preimage and is used to identify payments in the Lightning Network.
Implementations
Sourceimpl PaymentHash
impl PaymentHash
Sourcepub fn from_bytes(bytes: [u8; 32]) -> Self
pub fn from_bytes(bytes: [u8; 32]) -> Self
Create a new payment hash from bytes.
Sourcepub fn from_hex(hex: &str) -> Result<Self, LightningError>
pub fn from_hex(hex: &str) -> Result<Self, LightningError>
Create a new payment hash from a hex string.
Sourcepub fn verify(&self, preimage: &PaymentPreimage) -> bool
pub fn verify(&self, preimage: &PaymentPreimage) -> bool
Verify that a preimage matches this payment hash.